@@ -278,8 +278,8 @@ class OpenEuler():
             log.warning(f"{rpm} does not match the pattern")
             return None
 
-    def get_openEuler_everything_pkgs(
-            self, os_version: str, os_arch: str
+    def get_openEuler_pkgs(
+            self, os_version: str, os_arch: str, scope: str
     ) -> Generator[str, None, None]:
         """
         从 openEuler everything 源页面迭代        以迭代方式返回指定版本、架构的所有 RPM 包完整名称。
@@ -287,7 +287,7 @@ class OpenEuler():
         Args:
             os_version: openEuler 版本号（如 "24.03-LTS-SP2"）
             os_arch: 系统架构（如 "x86_64", "aarch64"）
-
+            scope: openEuler官方镜像源上软件包的范围，可选值 everything，epol，update
         Yields:
             str: RPM 包完整名称（如 "zvbi-devel-0.2.44-1.oe2403sp2.x86_64.rpm"）
 
@@ -295,14 +295,14 @@ class OpenEuler():
             RuntimeError: 网络请求失败（如超时、404、500 等）
             ValueError: 页面解析失败（未找到任何 .rpm 包）
         """
-        base_url_template = "https://dl-cdn.openeuler.openatom.cn/openEuler-{os_version}/everything/{os_arch}/Packages/"
+        base_url_template = "https://dl-cdn.openeuler.openatom.cn/openEuler-{os_version}/{scope}/{os_arch}/Packages/"
         timeout = 15
         headers = {
             "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36",
             "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8"
         }
 
-        target_url = base_url_template.format(os_version=os_version, os_arch=os_arch)
+        target_url = base_url_template.format(os_version=os_version, os_arch=os_arch,scope= scope)
 
         try:
             with requests.Session() as session:
@@ -321,7 +321,8 @@ class OpenEuler():
                 html_content = response.text
 
         except requests.exceptions.RequestException as e:
-            raise RuntimeError(f"获取页面失败！URL: {target_url}, 错误: {str(e)}") from e
+            log.error(f"获取页面失败！URL: {target_url}, 错误: {str(e)}")
+            return
 
         soup = BeautifulSoup(html_content, "html.parser")
         # 精确匹配.rpm链接，排除父目录和空链接
@@ -331,7 +332,8 @@ class OpenEuler():
         )
 
         if not pkg_links:
-            raise ValueError(f"页面解析失败！URL: {target_url}, 未找到任何 .rpm 包")
+            log.error(f"页面解析失败！URL: {target_url}, 未找到任何 .rpm 包")
+            return
 
         for link in pkg_links:
             full_pkg_name = link.get("href", "").strip()
@@ -339,17 +341,52 @@ class OpenEuler():
                 pkg_name=self.get_rpm_name_from_full_name(full_pkg_name)
                 yield pkg_name,full_pkg_name
 
+    def get_openEuler_all_rpm_list(self, os_version: str, os_arch: str):
+        """
+        获取指定版本、架构的所有 RPM 包完整名称。
+
+        Args:
+            os_version: openEuler 版本号（如 "24.03-LTS-SP2"）
+            os_arch: 系统架构（如 "x86_64", "aarch64"）
+
+        Returns:
+            list[str]: 包完整名称列表（如 ["zvbi-devel-0.2.44-1.oe2403sp2.x86_64.rpm", ...]）
+        """
+        all_rpm_list=[]
+        for rpm_name,_ in self.get_openEuler_pkgs(os_version, os_arch, "everything"):
+            if rpm_name not in all_rpm_list:
+                all_rpm_list.append(rpm_name)
+        for rpm_name,_ in self.get_openEuler_pkgs(os_version, os_arch, "EPOL"):
+            if rpm_name not in all_rpm_list:
+                all_rpm_list.append(rpm_name)
+        for rpm_name,_ in self.get_openEuler_pkgs(os_version, os_arch, "update"):
+            if rpm_name not in all_rpm_list:
+                all_rpm_list.append(rpm_name)
+        return all_rpm_list
+
 
 
 if __name__ == "__main__":
     # 初始化获取器
     oe = OpenEuler()
-    count=0
-    effective_count=0
-    for rpm_name,rpm_full_name in oe.get_openEuler_everything_pkgs("24.03-LTS-SP1", "x86_64"):
-        count+=1
-        print(f"{rpm_name}：{rpm_full_name}")
-    print(f"共获取到 {count} 个包")
+    rs=oe.get_openEuler_all_rpm_list("24.03-LTS-SP2", "x86_64")
+    print(f"total {len(rs)} pkgs")
+    # count=0
+    # effective_count=0
+    # for rpm_name,rpm_full_name in oe.get_openEuler_pkgs("24.03-LTS-SP1", "x86_64", "everything"):
+    #     count+=1
+    #     # print(f"{rpm_name}：{rpm_full_name}")
+    # print(f"everything 共获取到 {count} 个包")
+    # count = 0
+    # for rpm_name,rpm_full_name in oe.get_openEuler_pkgs("24.03-LTS-SP1", "x86_64", "EPOL"):
+    #     count+=1
+    #     # print(f"{rpm_name}：{rpm_full_name}")
+    # print(f"EPOL 共获取到 {count} 个包")
+    # count = 0
+    # for rpm_name,rpm_full_name in oe.get_openEuler_pkgs("24.03-LTS-SP1", "x86_64", "update"):
+    #     count+=1
+    #     # print(f"{rpm_name}：{rpm_full_name}")
+    # print(f"update 共获取到 {count} 个包")
     # for rpm in oe.get_openEuler_rpm_names_from_repo("24.03-LTS-SP2", "python-minio","https://gitee.com/src-openeuler/python-minio.git"):
     #     print(f"src_name:python-minio,rpm:{rpm}")
     # log.info("正在初始化 Gitee 模块...")
